﻿
using System.Windows;
using System.Windows.Controls;
using MindFusion.Scheduling.Wpf;
using System.Windows.Data;
using System.Globalization;
using System;
using System.Collections.Generic;
using System.Data;
using System.Windows.Media;
using System.Collections.ObjectModel;


namespace EnabledView
{
	public class CustomCellPresenter : CellPresenter
	{
		static CustomCellPresenter()
		{
			DefaultStyleKeyProperty.OverrideMetadata(typeof(CustomCellPresenter),
				new FrameworkPropertyMetadata(typeof(CustomCellPresenter)));
			IsSelectedProperty.OverrideMetadata(typeof(CustomCellPresenter),
				new PropertyMetadata(OnIsSelectedChanged));
		}

		public CustomCellPresenter(MindFusion.Scheduling.Wpf.Calendar calendar, ObservableCollection<DateTime> disabledDates)
			: base(calendar)
		{
			this.disabledDates = disabledDates;

			disabledDates.CollectionChanged += (s, e) =>
				{
					if (e.NewItems != null)
					{
						foreach (DateTime date in e.NewItems)
							if (date.Date == StartTime.Date)
								IsEnabled = false;
					}

					UpdateBackground();
				};
		}

		protected override void OnStartTimeChanged(DateTime oldTime, DateTime newTime)
		{
			base.OnStartTimeChanged(oldTime, newTime);

			IsEnabled = !disabledDates.Contains(newTime.Date);

			UpdateBackground();
		}

		private static void OnIsSelectedChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
		{
			((CustomCellPresenter)d).UpdateBackground();
		}

		private void UpdateBackground()
		{
			if (!IsEnabled && !IsSelected)
			{
				Background2 = new SolidColorBrush(Color.FromArgb(255, 235, 245, 255));
			}
			else
			{
				ClearValue(Background2Property);
				SetBinding(Background2Property, new Binding("Background") { Source = this });
			}
		}


		public Brush Background2
		{
			get { return (Brush)GetValue(Background2Property); }
			set { SetValue(Background2Property, value); }
		}

		public static readonly DependencyProperty Background2Property =
			DependencyProperty.Register("Background2", typeof(Brush), typeof(CustomCellPresenter), new PropertyMetadata(null));


		ObservableCollection<DateTime> disabledDates;
	}

	public class BooleanToVisibilityConverter : IValueConverter
	{
		public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
		{
			if (value is bool)
			{
				bool not = false;
				if (parameter != null)
				{
					if (!bool.TryParse(parameter.ToString(), out not))
						not = false;
				}

				return (not ^ (bool)value) ? Visibility.Visible : Visibility.Collapsed;
			}

			return value;
		}

		public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
		{
			throw new System.NotImplementedException();
		}
	}
}
